SET NAMES 'UTF8';

-- Corrección de ID de Forma de Pago (Base 1)
UPDATE tbl_movimientos_pagos
SET id_forma_pago = id_forma_pago + 1;

-- Actualizacion de rutas de sincronizacion
UPDATE cat_configuracion
SET url_sync_cortes = 'http://hks.softnet.com.mx/ERP/api/sync_cortes_caja.php',
	url_sync_retiros = 'http://hks.softnet.com.mx/ERP/api/sync_retiros.php';

DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_listarPedidos`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_listarPedidos`(
	in_tipo_movimiento INT,
	in_fecha DATE
)
    COMMENT 'Recupera los pedidos que no se han pagado aun'
BEGIN
	CASE in_tipo_movimiento
		WHEN 1 THEN
			
			SELECT mov.id_movimiento,
				mov.consecutivo,
				mov.fecha,
				mov.hora,
				CONCAT(IF(ISNULL(mov.fecha_cancelado), '', 'CANCELADO - '), mov.referencia) AS referencia,
				u.nombre AS nombre_vendedor,
				mov.total,
				mov.total - mov.pagado AS saldo,
				IF(ISNULL(mov.consolidado), '', 'OK') AS txt_enviada,
				1 AS activo,
				IF(ISNULL(mov.consolidado), 0, 1) AS enviado,
				mov.pagado,
				GROUP_CONCAT(ELT(mp.id_forma_pago,'Efectivo','T. Débito','T. Crédito','Depósito','Transferencia','Nota Crédito')) AS forma_pago,
				IF(mov.factura = 1, 'SI', '') AS factura
			FROM tbl_movimientos AS mov
			JOIN tbl_usuarios AS u
				ON u.id_user = mov.id_usuario_venta
			LEFT OUTER JOIN tbl_movimientos_pagos AS mp
				ON mp.id_movimiento = mov.id_movimiento
			WHERE mov.pagado <> mov.total
				AND mov.fecha_cancelado IS NULL
			GROUP BY mov.id_movimiento;
		WHEN 2 THEN
			
			SELECT mov.id_movimiento,
				mov.consecutivo,
				mov.fecha,
				mov.hora,
				CONCAT(IF(ISNULL(mov.fecha_cancelado), '', 'CANCELADO - '), mov.referencia) AS referencia,
				u.nombre AS nombre_vendedor,
				mov.total,
				mov.total - mov.pagado AS saldo,
				IF(ISNULL(mov.consolidado), '', 'OK') AS txt_enviada,
				0 AS activo,
				IF(ISNULL(mov.consolidado), 0, 1) AS enviado,
				mov.pagado,
				GROUP_CONCAT(ELT(mp.id_forma_pago,'Efectivo','T. Débito','T. Crédito','Depósito','Transferencia','Nota Crédito')) AS forma_pago,
				IF(mov.factura = 1, 'SI', '') AS factura
			FROM tbl_movimientos AS mov
			JOIN tbl_usuarios AS u
				ON u.id_user = mov.id_usuario_venta
			LEFT OUTER JOIN tbl_movimientos_pagos AS mp
				ON mp.id_movimiento = mov.id_movimiento
			WHERE mov.pagado = mov.total
				AND mov.fecha = in_fecha
			GROUP BY mov.id_movimiento;
		WHEN 3 THEN
			
			SELECT mov.id_movimiento,
				mov.consecutivo,
				mov.fecha,
				mov.hora,
				CONCAT(IF(ISNULL(mov.fecha_cancelado), '', 'CANCELADO - '), mov.referencia) AS referencia,
				u.nombre AS nombre_vendedor,
				mov.total,
				mov.total - mov.pagado AS saldo,
				IF(ISNULL(mov.consolidado), '', 'OK') AS txt_enviada,
				0 AS activo,
				IF(ISNULL(mov.consolidado), 0, 1) AS enviado,
				mov.pagado,
				GROUP_CONCAT(ELT(mp.id_forma_pago,'Efectivo','T. Débito','T. Crédito','Depósito','Transferencia','Nota Crédito')) AS forma_pago,
				IF(mov.factura = 1, 'SI', '') AS factura
			FROM tbl_movimientos AS mov
			JOIN tbl_usuarios AS u
				ON u.id_user = mov.id_usuario_venta
			LEFT OUTER JOIN tbl_movimientos_pagos AS mp
				ON mp.id_movimiento = mov.id_movimiento
			WHERE mov.fecha_cancelado IS NOT NULL
				AND mov.fecha = in_fecha
			GROUP BY mov.id_movimiento;
		WHEN 4 THEN
			
			SELECT mov.id_movimiento,
				mov.consecutivo,
				mov.fecha,
				mov.hora,
				CONCAT(IF(ISNULL(mov.fecha_cancelado), '', 'CANCELADO - '), mov.referencia) AS referencia,
				u.nombre AS nombre_vendedor,
				mov.total,
				mov.total - mov.pagado AS saldo,
				IF(ISNULL(mov.consolidado), '', 'OK') AS txt_enviada,
				IF(mov.pagado <> mov.total AND ISNULL(mov.fecha_cancelado), 1, 0) AS activo,
				IF(ISNULL(mov.consolidado), 0, 1) AS enviado,
				mov.pagado,
				GROUP_CONCAT(ELT(mp.id_forma_pago,'Efectivo','T. Débito','T. Crédito','Depósito','Transferencia','Nota Crédito')) AS forma_pago,
				IF(mov.factura = 1, 'SI', '') AS factura
			FROM tbl_movimientos AS mov
			JOIN tbl_usuarios AS u
				ON u.id_user = mov.id_usuario_venta
			LEFT OUTER JOIN tbl_movimientos_pagos AS mp
				ON mp.id_movimiento = mov.id_movimiento
			WHERE mov.fecha = in_fecha
			GROUP BY mov.id_movimiento
			; 
	END CASE;
END$$

DELIMITER ;

DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_efectivoEnCaja`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_efectivoEnCaja`()
    SQL SECURITY INVOKER
    COMMENT 'Obtiene el importe de efectivo en caja actualmente'
BEGIN
	DECLARE efectivo DECIMAL(15,2);
	DECLARE retiros DECIMAL(15,2);
	DECLARE pagos DECIMAL(15,2);
	DECLARE fecha_corte DATETIME;
	SET efectivo = 0;
	SET retiros = 0;
	SET pagos = 0;
	SET fecha_corte = '2000-01-01';
	
	
	SELECT cc.efectivo_real, cc.fecha_corte INTO efectivo, fecha_corte
	FROM tbl_cortes_caja AS cc
	ORDER BY cc.fecha_corte DESC
	LIMIT 1;
	
	
	SELECT SUM(re.retiro) INTO retiros
	FROM tbl_retiros AS re
	WHERE re.fecha_retiro >= fecha_corte;
	
	
	SELECT SUM(p.importe_cobro - p.cambio) INTO pagos
	FROM tbl_movimientos_pagos AS p
	WHERE p.fecha_pago >= fecha_corte
		AND p.id_forma_pago = 1;
	
	
	SELECT efectivo + COALESCE(pagos, 0) - COALESCE(retiros, 0) AS efectivo,
		efectivo AS caja, COALESCE(pagos, 0) AS pagos, COALESCE(retiros, 0) AS retiros;
END$$

DELIMITER ;
